package rvl.swv;

/**
  This class contains the essential information for a graphics that
  is created by a statistical engine.
 */
public class FigFile {

    /** name of file */
    String fileName;

    /** File format */
    int format = PDF;

    /** True width, in inches */
    double width = 6.0;

    /** True height, in inches */
    double height = 6.0;

    /** Number of pages (0 when no multipage capability) */
    int pages;


    /* graph formats */

    /** no graph format */ public static final int      NULL = 0;
    /** PDF graph format */ public static final int     PDF = 1;
    /** JPG graph format */ public static final int     JPG = 2;
    /** PNG graph format */ public static final int     PNG = 3;
    /** PostScript graph format */ public static final int     PS  = 4;
    /** TIF graph format */ public static final int     TIF = 5;
    /** GIF graph format */ public static final int     GIF = 6;
    /** BMP graph format */ public static final int     BMP = 7;
    /** EPS graph format */ public static final int     EPS = 8;

    /** Labels in 1-1 correspondence with graph format values;
    for example, <tt>labels[PDF]</tt> equals <tt>"pdf"</tt>.
    All these labels are purely lower-case.
    */
    static final String[] labels = new String[] {
        "", "pdf", "jpg", "png", "ps", "tif", "gif", "bmp", "eps"
    };

    /** Constructor */
    public FigFile (String fileName, int format, double width, double height, int pages) {
        this.fileName = fileName;
        this.format = format;
        this.width = width;
        this.height = height;
        boolean multipage = (format == PDF || format == PS || format == TIF);
        this.pages = multipage ? pages : 0;
    }

    /** Return internal constant for given name */
    public static int fmtID(String name) {
        if (name == null) return NULL;
        else if (name.equalsIgnoreCase("PDF")) return PDF;
        else if (name.equalsIgnoreCase("JPG")) return JPG;
        else if (name.equalsIgnoreCase("PNG")) return PNG;
        else if (name.equalsIgnoreCase("PS")) return PS;
        else if (name.equalsIgnoreCase("TIF")) return TIF;
        else if (name.equalsIgnoreCase("GIF")) return GIF;
        else if (name.equalsIgnoreCase("BMP")) return BMP;
        else if (name.equalsIgnoreCase("EPS")) return EPS;
        else return NULL;
    }

    // accessor methods
    public int getFormat() {
        return format;
    }

    public String getFileName() {
        return fileName;
    }

    public int getPages() {
        return pages;
    }

    public double getWidth() {
        return width;
    }

    public double getHeight() {
        return height;
    }

}
