package rvl.swv;
import rvl.swv.*;
import java.io.*;

/**
  Engine for S-Plus code.  Present version suppresses all echoing of
  code, and all output produced by a code chunk comes at the end.
  This is not <TT>Sweave</TT>'s behavior.
 */
public class SplusEngine extends AbstractEngine {

    public SplusEngine() {
        engineName = "SplusEngine";
        codeExt = ".q";
        outExt = ".Sout";
        commentStart = "# ";
        commentEnd = "";
        okfigfmts = new int[] {FigFile.PDF, FigFile.PS, FigFile.PNG, FigFile.JPG};
        startupCode = "options(echo=FALSE)";
    }


    public void putSeparator(String text) {
        putCode("cat(\"" + text + "\\n\")");
    }

// Have to use cat so we don't get obs number
    public void putExpr(String expr) {
        putCode("cat(paste(" + expr + ", \"\\n\"))");
    }

    public FigFile setupFig(String chunkName) {
        FigFile fig = super.setupFig(chunkName);
        if (fig != null) {
            int fmt = fig.getFormat();
            String cmd = "pdf.graph", extargs = "";
            double wid = fig.getWidth(), ht = fig.getHeight();
            if (fmt == FigFile.PNG || fmt == FigFile.JPG) {
                cmd = "java.graph";
                wid *= 72; ht *= 72;
                extargs = ", format=\"" + (fmt==FigFile.PNG ? "PNG" : "JPEG") + "\"";
            }
            else if (fmt == FigFile.PS) {
                cmd = "postscript";
                extargs = ", ps.horizontal = FALSE";
            }
            cmd = cmd + "(\"" + fig.getFileName() + "\", width=" + wid
                + ", height=" + ht + extargs + ")";
            putCode(cmd);
        }
        return fig;
    }

    public void closeFig() {
        putCode("dev.off()");
    }



} // ----- END OF SplusEngine -------

